/*
 *  This file is part of xMule2.
 *  Copyright (C) 2003 Alo Sarv <madcat_@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
#ifdef __GNUG__
	#pragma implementation "GUISettingsDlg.cpp"
#endif

// For compilers that support precompilation, includes "wx/wx.h".
#include "wx/wxprec.h"

#ifdef __BORLANDC__
	#pragma hdrstop
#endif

#include "GUISettingsDlg.h"
#include "xMuleDlg.h"

BEGIN_EVENT_TABLE(CGUISettingsDlg, wxDialog)
	EVT_BUTTON(GUI_OK, CGUISettingsDlg::OnOk)
	EVT_BUTTON(GUI_CANCEL, CGUISettingsDlg::OnCancel)
	EVT_CHECKBOX(ID_REMEMBER_LAST, CGUISettingsDlg::OnCheckRememberLast)
END_EVENT_TABLE()

/* Constructor for GUI Settings dialog. */
CGUISettingsDlg::CGUISettingsDlg(
	wxWindow *parent, wxWindowID id, const wxString &title,
	const wxPoint &position, const wxSize &size, long style
) : wxDialog(parent, id, title, position, size, style) {
	Dlg_GUI_Settings(this, true, true);
	Center();
	/* Load or Create the config object */
	config = wxConfigBase::Get();

	LoadSettings();
}

/*
 * Handles GUI Settings dialog Ok button event - Saves the settings and
 * closes the dialog.
 */
void CGUISettingsDlg::OnOk(wxCommandEvent &event) {
	SaveSettings();
	EndModal(0);
}

/*
 * Handles GUI Settings dialog Cancel button event - closes the dialog.
 */
void CGUISettingsDlg::OnCancel(wxCommandEvent &event) {
	EndModal(0);
}

/*
 * Loads settings from config object and sets up dialog controls values.
 */
void CGUISettingsDlg::LoadSettings() {
	/* Settings fields initialization and default settings */
	wxString username;
	int	language;
	int	font;
	int	iconset;
	bool show_splash;
	bool prompt_exit;
	bool show_toolbar;
	int tool_align;
	bool show_menubar;
	int startpage;
	bool remember_last;

	/* Read from config. If no value found, &<field> remains unchanged */
	config->SetPath(wxT("/General"));
	config->Read(wxT("Username"), &username, wxT("xMule2 user"));
	config->Read(wxT("Language"), &language, 0);
	config->Read(wxT("Font"), &font, 0);
	config->Read(wxT("Icon set"), &iconset, 0);
	config->Read(wxT("Show splashscreen"), &show_splash, true);
	config->Read(wxT("Prompt on exit"), &prompt_exit, true);
	config->Read(wxT("Show toolbar"), &show_toolbar, true);
	config->Read(wxT("Toolbar alignment"), &tool_align, 0);
	config->Read(wxT("Show menubar"), &show_menubar, false);
	config->Read(wxT("Start page"), &startpage, 0);
	config->Read(wxT("Remember last"), &remember_last, true);

	/* Set controls values to match config values */
	GetNick()->SetValue(username);
	GetLang()->SetSelection(language);
	GetFont()->SetSelection(font);
	GetIconset()->SetSelection(iconset);
	GetShowsplash()->SetValue(show_splash);
	GetPromptexit()->SetValue(prompt_exit);
	GetShowtool()->SetValue(show_toolbar);
	GetShowmenu()->SetValue(show_menubar);
	GetRememberLast()->SetValue(remember_last);
	GetStartpage()->SetSelection(startpage);

	switch (tool_align) {
		case wxTB_HORIZONTAL:	tool_align = 0; break;
		case wxTB_VERTICAL:		tool_align = 1; break;
		default: break;
	}
	GetToolalign()->SetSelection(tool_align);

	if (GetRememberLast()->GetValue()) {
		GetStartpage()->Disable();
	}
}

/*
 * Writes control values to config object.
 */
void CGUISettingsDlg::SaveSettings() {
	int old_tool_align, tool_align;

	config->SetPath(wxT("/General"));
	config->Write(wxT("Username"), GetNick()->GetValue());
	config->Write(wxT("Language"), GetLang()->GetSelection());
	config->Write(wxT("Font"), GetFont()->GetSelection());
	config->Write(wxT("Icon set"), GetIconset()->GetSelection());
	config->Write(wxT("Show splashscreen"), GetShowsplash()->GetValue());
	config->Write(wxT("Prompt on exit"), GetPromptexit()->GetValue());
	config->Write(wxT("Show toolbar"), GetShowtool()->GetValue());
	config->Write(wxT("Show menubar"), GetShowmenu()->GetValue());
	config->Write(wxT("Start page"), GetStartpage()->GetSelection());
	config->Write(wxT("Remember last"), GetRememberLast()->GetValue());

	tool_align = GetToolalign()->GetSelection();
	switch (tool_align) {
		case 0: tool_align = wxTB_HORIZONTAL; break;
		case 1: tool_align = wxTB_VERTICAL; break;
		default: break;
	}
	
	/**
	 * If toolbar alignment was changed, notify the user that the change
	 * requires restart.
	 */
	config->Read(wxT("Toolbar alignment"), &old_tool_align);
	if (old_tool_align != tool_align) {
		::wxMessageBox(wxT("For toolbar alignment change to take\n"
			"effect, restart of the interface is required."), 
			wxT("Notice"), wxOK|wxCENTRE|wxICON_INFORMATION);
	}
	config->Write(wxT("Toolbar alignment"), tool_align);
}

/*
 * Handles checking/unchecking Remember Last checkbox - enables/disables
 * startpage selection combobox as neccesery.
 */
void CGUISettingsDlg::OnCheckRememberLast(wxCommandEvent &event) {
	if (GetRememberLast()->GetValue()) {
		GetStartpage()->Disable();
	} else {
		GetStartpage()->Enable();
	}
}
