/*
 *  This file is part of xMule2.
 *  Copyright (C) 2003 Alo Sarv <madcat_@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __TransferWnd_H__
#define __TransferWnd_H__

#ifdef __GNUG__
	#pragma interface "TransferWnd.cpp"
#endif

#ifndef WX_PRECOMP
	#include "wx/wx.h"
#endif

/* Global includes for resources */
#include "xMuleGUI_wdr.h"
#include "defines.h"

/* Private includes for list control classes */
#include "DownloadListCtrl.h"
#include "UploadListCtrl.h"
#include "QueueListCtrl.h"
#include "KnownListCtrl.h"

class CTransferWnd: public wxPanel {
public:
	/* Public functions */
	CTransferWnd(
		wxWindow *parent, wxWindowID id = -1, 
		const wxPoint& pos = wxDefaultPosition,
		const wxSize& size = wxDefaultSize,
		long style = wxTAB_TRAVERSAL | wxNO_BORDER | 
		wxNO_FULL_REPAINT_ON_RESIZE
	);
	virtual ~CTransferWnd();

	/* Public variables */
	CDownloadListCtrl* m_dlistctrl;
	CUploadListCtrl* m_ulistctrl;
	CQueueListCtrl* m_qlistctrl;
	CKnownListCtrl* m_klistctrl;
    
private:
	DECLARE_EVENT_TABLE()
	
	/* Member event handler functions */
	void ChangeToQueue();
	void ChangeToKnown();
	void ChangeToUpload();
	
	/* Member layout generation functions */
	void CreateControls();
	wxSizer* DownloadPanel(wxWindow* parent);
	wxSizer* UploadPanel(wxWindow* parent);
	wxSizer* QueuePanel(wxWindow* parent);
	wxSizer* KnownPanel(wxWindow* parent);
	
	/* Member variable declarations */
	wxSplitterWindow *splatter;
	wxPanel *download;
	wxPanel *upload;
	wxPanel *queue;
	wxPanel *known;
	wxConfigBase *config;
};


#endif
