/*
 *  This file is part of xMule2.
 *  Copyright (C) 2003 Alo Sarv <madcat_@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifdef __GNUG__
	#pragma implementation "xMuleDlg.h"
#endif

// For compilers that support precompilation
#include "wx/wxprec.h"

#ifdef __BORLANDC__
	#pragma hdrstop
#endif

#include "xMuleDlg.h"

/*
 * xMuleDlg class. The main dialog functions like Toolbar and Statusbar
 * stuff go in here.
 */

BEGIN_EVENT_TABLE(xMuleDlg,wxFrame)
	/* Shutdown events */
	EVT_CLOSE(xMuleDlg::OnCloseWindow)
	
	/* Main toolbar button events */
	EVT_TOOL(ID_BTN_CONNECT, xMuleDlg::OnBtnConnect)
	EVT_TOOL(ID_BTN_SERVERS, xMuleDlg::ToolbarButtonClicked)
	EVT_TOOL(ID_BTN_SEARCH, xMuleDlg::ToolbarButtonClicked)
	EVT_TOOL(ID_BTN_TRANSFER, xMuleDlg::ToolbarButtonClicked)
	EVT_TOOL(ID_BTN_SHARED, xMuleDlg::ToolbarButtonClicked)
	EVT_TOOL(ID_BTN_MESSAGES, xMuleDlg::ToolbarButtonClicked)
	EVT_TOOL(ID_BTN_STATISTICS, xMuleDlg::ToolbarButtonClicked)
	EVT_TOOL(ID_BTN_GUISETTINGS, xMuleDlg::OnBtnGUISettings)
	EVT_TOOL(ID_BTN_CORESETTINGS, xMuleDlg::OnBtnCoreSettings)
END_EVENT_TABLE()

/*
 * Main dialog constructor. Creates toolbar on the top, statusbar on the
 * bottom and loads the sub-dialogs (serverwnd, searchwnd etc).
 */
xMuleDlg::xMuleDlg(
	wxWindow *parent, wxWindowID id, const wxString &title,
	const wxPoint &position, const wxSize& size, long style
) 
: wxFrame( parent, id, title, position, size, style ) {
	int height, width, posx, posy;

	config = wxConfigBase::Get();

	/* Create toolbar and statusbar */
	CreateMyToolBar();
	m_statusbar = new StatusBar(this);
	SetStatusBar(m_statusbar);
	
	/* Set application icon */
	wxIcon icon;
	icon.CopyFromBitmap(Icons(10));
	SetIcon(icon);

	CreateSysTray();

	/* This adds a new sizer in the frame to make switching pages easier. */
	m_mainsizer = ContentSizer(this, true);
	LoadAndShowDialogPages();

	config->Read(wxT("Frame/Height"), &height, 600);
	config->Read(wxT("Frame/Width"), &width, 800);
	config->Read(wxT("Frame/PosX"), &posx, 20);
	config->Read(wxT("Frame/PosY"), &posy, 20);
	SetSize(width, height);
	Move(posx, posy);

	serverwnd->AddLogLine(wxT("xMule v2 ready!"), true);
}

/*
 * Destructor for xMuleDlg.
 */
xMuleDlg::~xMuleDlg() {
	config->SetPath(wxT("/Frame"));
	config->Write(wxT("Height"), GetSize().GetHeight());
	config->Write(wxT("Width"), GetSize().GetWidth());
	config->Write(wxT("PosX"), GetPosition().x);
	config->Write(wxT("PosY"), GetPosition().y);
	config->Write(wxT("SashPosition"), splitterwnd->GetSashPosition());

	/* 
	 * If we are instructed to remember the last open page between sessions,
	 * write current active page to config file. This is done by determining
	 * which toolbar button is currently selected (stored in m_lastbtn variable)
	 * and substracting 1001 from that value to get 0 for serverwnd, 1 for 
	 * transferwnd etc, thus matching the codes we use from CGUISettingsDlg
	 * class.
	 */
	int remember_last;
	config->Read(wxT("/General/Remember last"), &remember_last, true);
	if (remember_last) {
		config->Write(wxT("/General/Start page"), m_lastbtn-1001);
	}

	#ifdef __WXMSW__
		taskbar->RemoveIcon();
	#endif
}

/*
 * Creates an icon to System Tray/Taskbar/Notification Area.
 */
void xMuleDlg::CreateSysTray() {
	/* Windows */
#ifdef __WXMSW__
	wxIcon icon;
	icon.CopyFromBitmap(Icons(10));
	taskbar = new wxTaskBarIcon();
	taskbar->SetIcon(icon, wxT("xMule v2"));
#endif
	/* Linux */
	
	/* Mac OS X */

}

/*
 * Changes content of the main frame by removing the old panel from m_mainsizer
 * and attaching new one. [start_up] defaults to false, and is required true
 * if we are calling this function on application start-up (don't hide old
 * (nonexistent) frame then).
 */
void xMuleDlg::SetActiveDialog(wxWindow* dlg, bool start_up) {
	/* On startup, we don't have activewnd here yet, so don't hide anything. */
	if (!start_up) {
		activewnd->Show(FALSE);
		m_mainsizer->Remove(activewnd);
	}
	m_mainsizer->Add(dlg,1,wxALIGN_LEFT|wxEXPAND|wxALL);
	dlg->Show(TRUE);
	activewnd=dlg;
	Layout();
}

/*
 * Creates the toolbar on the top end of the main dialog.
 */
void xMuleDlg::CreateMyToolBar() {
	int tool_align;
	config->Read(wxT("/General/Toolbar alignment"), &tool_align, wxTB_HORIZONTAL);
	/* Construct the toolbar object */
	tb = CreateToolBar(
 		tool_align|wxNO_BORDER|wxTB_TEXT|wxTB_FLAT|wxTB_3DBUTTONS
   	);
	tb->SetToolBitmapSize(wxSize(32, 32));
	tb->SetMargins( 2, 2 );

	/* Load images */
	wxBitmap img_connect(_T("images/default/btn_connect.png"), wxBITMAP_TYPE_PNG);
	wxBitmap img_servers(_T("images/default/btn_servers.png"), wxBITMAP_TYPE_PNG);
	wxBitmap img_transfer(_T("images/default/btn_transfer.png"), wxBITMAP_TYPE_PNG);
	wxBitmap img_search(_T("images/default/btn_search.png"), wxBITMAP_TYPE_PNG);
	wxBitmap img_shared(_T("images/default/btn_shared.png"), wxBITMAP_TYPE_PNG);
	wxBitmap img_messages(_T("images/default/btn_messages.png"), wxBITMAP_TYPE_PNG);
	wxBitmap img_statistics(_T("images/default/btn_statistics.png"), wxBITMAP_TYPE_PNG);
	wxBitmap img_guisettings(_T("images/default/btn_guisettings.png"), wxBITMAP_TYPE_PNG);
	wxBitmap img_preferences(_T("images/default/btn_preferences.png"), wxBITMAP_TYPE_PNG);

	/* Add the buttons */
	tb->AddTool(
		ID_BTN_CONNECT, _("Connect"), img_connect, 
		wxNullBitmap, wxITEM_NORMAL, _("Connect to any server") 
	);
	tb->AddSeparator();
	tb->AddTool(
		ID_BTN_SERVERS, _("Servers"), img_servers, 
		wxNullBitmap, wxITEM_CHECK, _("Server list")
	);
	tb->AddTool(
		ID_BTN_TRANSFER, _("Transfer"), img_transfer, 
		wxNullBitmap, wxITEM_CHECK, _("File Transfer")
	);
	tb->AddTool( 
		ID_BTN_SEARCH, _("Search"), img_search, 
		wxNullBitmap, wxITEM_CHECK, _("Search files") 
	);
	tb->AddTool(
		ID_BTN_SHARED, _("Shared Files"), img_shared, 
		wxNullBitmap, wxITEM_CHECK, _("Show shared files")
	);
	tb->AddTool(
		ID_BTN_MESSAGES, _("Messages"), img_messages, 
		wxNullBitmap, wxITEM_CHECK, _("Chatting") 
	);
	tb->AddTool(
		ID_BTN_STATISTICS, _("Statistics"), img_statistics, 
		wxNullBitmap, wxITEM_CHECK, _("Show live statistics") );
	tb->AddSeparator();
	tb->AddTool(
		ID_BTN_GUISETTINGS, _("GUI Settings"), img_guisettings, 
		wxNullBitmap, wxITEM_NORMAL, _("User Interface Settings")
	);
	tb->AddTool(
		ID_BTN_CORESETTINGS, _("Core Settings"), img_preferences, 
		wxNullBitmap, wxITEM_NORMAL, _("Change limits, ports etc")
	);

	/* And go live */
	tb->Realize();
}

/*
 * CloseWindow event function. This should destroy all open dialogs.
 */
void xMuleDlg::OnCloseWindow( wxCloseEvent &event ){
	/* Read from config if we should ask for permission before closing. */
	bool prompt_exit;
	config->Read(wxT("/General/Prompt on exit"), &prompt_exit, true); 

	if (prompt_exit) {
		if (wxMessageBox(wxT("Close xmule2-ui-wx?"), wxT("Question"), wxYES_NO|wxCENTRE|wxICON_QUESTION) == wxNO) {
			return;
		}
	}
	/* We reach this line if prompt_exit was false, 
	 * or Yes was clicked in messagebox 
	 */
	Destroy();
}

/*
 * Handles main toolbar button click events. Toggles the previously clicked
 * button off and new button on. Then shows the correct dialog.
 */
void xMuleDlg::ToolbarButtonClicked (wxCommandEvent &event) {
	
	tb->ToggleTool(m_lastbtn, false);
	tb->ToggleTool(event.GetId(), true);
	m_lastbtn = event.GetId();

	switch (event.GetId()) {
		case ID_BTN_SERVERS: 
			SetActiveDialog(serverwnd);
			break;
		case ID_BTN_TRANSFER:
			SetActiveDialog(transferwnd);
			break;
		case ID_BTN_SEARCH:  
			SetActiveDialog(searchwnd);
			break;
		case ID_BTN_SHARED:
			SetActiveDialog(sharedfileswnd);
			break;
		case ID_BTN_MESSAGES:
			SetActiveDialog(messageswnd);
			break;
		case ID_BTN_STATISTICS:
			SetActiveDialog(statisticswnd);
			break;
		default:
			break;
	}
}

/*
 * Handles Connect button clicks on main toolbar. Switches button layout as
 * needed and sends message to core to connect/abort connecting/disconnect.
 */
void xMuleDlg::OnBtnConnect(wxCommandEvent &event) {
}

/*
 * Handles Preferences button click on main toolbar. Displays the preferences
 * dialog.
 */
void xMuleDlg::OnBtnCoreSettings(wxCommandEvent &event) {
	CCoreSettingsDlg *coredlg = new CCoreSettingsDlg(
		NULL, -1, wxT("Core Settings"),wxDefaultPosition, wxDefaultSize
	);
	coredlg->ShowModal();
	delete coredlg;
}

/*
 * Handles GUI Settings button click on main toolbar. Displays the GUI settings
 * dialog.
 */
void xMuleDlg::OnBtnGUISettings(wxCommandEvent &event) {
	CGUISettingsDlg *guisettings = new CGUISettingsDlg(
		NULL, -1, wxT("User Interface Settings"), 
		wxDefaultPosition, wxDefaultSize
	);
	guisettings->ShowModal();
	delete guisettings;
}

void xMuleDlg::LoadAndShowDialogPages() {
	int start_page;

	serverwnd = new CServerWnd(this);
	searchwnd = new CSearchWnd(this);
	transferwnd = new CTransferWnd(this);
	sharedfileswnd = new CSharedFilesWnd(this);
	messageswnd = new CMessagesWnd(this);
	statisticswnd = new CStatisticsWnd(this);

	config->Read(wxT("/General/Start page"), &start_page, 0);
	switch (start_page) {
		case 0:
			SetActiveDialog(serverwnd, true);
			tb->ToggleTool(ID_BTN_SERVERS, true);
			m_lastbtn = ID_BTN_SERVERS;
			break;
		case 1:
			SetActiveDialog(transferwnd, true);
			tb->ToggleTool(ID_BTN_TRANSFER, true);
			m_lastbtn = ID_BTN_TRANSFER;
			break;
		case 2:
			SetActiveDialog(searchwnd, true);
			tb->ToggleTool(ID_BTN_SEARCH, true);
			m_lastbtn = ID_BTN_SEARCH;
			break;
		case 3:
			SetActiveDialog(sharedfileswnd, true);
			tb->ToggleTool(ID_BTN_SHARED, true);
			m_lastbtn = ID_BTN_SHARED;
			break;
		case 4:
			SetActiveDialog(messageswnd, true);
			tb->ToggleTool(ID_BTN_MESSAGES, true);
			m_lastbtn = ID_BTN_MESSAGES;
			break;
		case 5:
			SetActiveDialog(statisticswnd, true);
			tb->ToggleTool(ID_BTN_STATISTICS, true);
			m_lastbtn = ID_BTN_STATISTICS;
			break;
		default:
			SetActiveDialog(serverwnd, true);
			break;
	}
}
