/*
 *  This file is part of xMule2.
 *  Copyright (C) 2003 Alo Sarv <madcat_@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __xMuleDlg_H__
#define __xMuleDlg_H__

#ifdef __GNUG__
    #pragma interface "xMuleDlg.h"
#endif

// Include wxWindows' headers
#ifndef WX_PRECOMP
    #include <wx/wx.h>
#endif

/* Include local headers */
#include "xMuleGUI_wdr.h"
#include "defines.h"
#include "StatusBar.h"
#include "ServerWnd.h"
#include "TransferWnd.h"
#include "SearchWnd.h"
#include "SharedFilesWnd.h"
#include "MessagesWnd.h"
#include "StatisticsWnd.h"
#include "CoreSettingsDlg.h"
#include "GUISettingsDlg.h"

/*
 * Constants for xMuleDlg
 */

#define ID_QUIT     100
#define ID_ABOUT    101

/*
 * xMuleDlg class. The main dialog functions like Toolbar and Statusbar
 * stuff go in here.
 */
class xMuleDlg: public wxFrame
{
public:
	/* Constructors and destructors */
	xMuleDlg( wxWindow *parent, wxWindowID id, const wxString &title,
		const wxPoint& pos = wxDefaultPosition,
		const wxSize& size = wxDefaultSize,
		long style = wxDEFAULT_FRAME_STYLE );
	~xMuleDlg();

	CServerWnd *serverwnd;
	CSearchWnd *searchwnd;
	CTransferWnd *transferwnd;
	CSharedFilesWnd *sharedfileswnd;
	CMessagesWnd *messageswnd;
	CStatisticsWnd *statisticswnd;

private:
	DECLARE_EVENT_TABLE()
	
	/* Member event handler functions */
	void OnCloseWindow( wxCloseEvent &event );	
	void ToolbarButtonClicked(wxCommandEvent &event);
	void OnBtnConnect(wxCommandEvent &event);
	void OnBtnCoreSettings(wxCommandEvent &event);

	void OnBtnGUISettings(wxCommandEvent &event);
	void OnBtnGUIOk(wxCommandEvent &event);
	void OnBtnGUICancel(wxCommandEvent &event);
	
	/* Member functions */	
	void SetActiveDialog(wxWindow* dlg, bool start_up = false);
	void CreateMyToolBar();
	void CreateSysTray();
	void LoadAndShowDialogPages();
	
	/* Member variables */
	wxSizer *m_mainsizer; 	// Sizer to make dialog pages switching easier.
	wxToolBar *tb;		// Main toolbar
	int m_lastbtn;		// Last toggled toolbar button
	#ifdef __WXMSW__
		wxTaskBarIcon *taskbar;	// System Tray
	#endif
	wxConfigBase *config;
	wxStatusBar *m_statusbar;
		
	wxWindow *activewnd;
};


#endif
